summaryrefslogtreecommitdiffstats
path: root/skia/ext/convolver.h
diff options
context:
space:
mode:
authorpkasting@chromium.org <pkasting@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-09-24 01:14:52 +0000
committerpkasting@chromium.org <pkasting@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-09-24 01:14:52 +0000
commitcab34d6a13d3044c59cd5dccdf4b04725a395aac (patch)
treed9c05fd2e59a12cedf72f97d8cb4c420ff4793bb /skia/ext/convolver.h
parent37cc1a1eaaa0c425a1ba889cf619f464227f9906 (diff)
downloadchromium_src-cab34d6a13d3044c59cd5dccdf4b04725a395aac.zip
chromium_src-cab34d6a13d3044c59cd5dccdf4b04725a395aac.tar.gz
chromium_src-cab34d6a13d3044c59cd5dccdf4b04725a395aac.tar.bz2
Move functions from skia/ext to app/gfx where possible: most of skia_utils.* and image_operations.* can be moved because they are not used by WebKit code.
This also fixes the spelling of "Convolusion" to "Convolution" and updates some copyrights. This is a re-do of r26975, this time with WebKit update and some fixes to compile on Mac and Linux. BUG=none TEST=none git-svn-id: svn://svn.chromium.org/chrome/trunk/src@27031 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'skia/ext/convolver.h')
-rw-r--r--skia/ext/convolver.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/skia/ext/convolver.h b/skia/ext/convolver.h
index 91c7ccb..1f38282 100644
--- a/skia/ext/convolver.h
+++ b/skia/ext/convolver.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2006-2008 The Chromium Authors. All rights reserved.
+// Copyright (c) 2009 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -18,18 +18,18 @@ namespace skia {
// object for the filter values contributing to it. You build up the filter
// list by calling AddFilter for each output pixel (in order).
//
// We do 2-dimensional convolusion by first convolving each row by one
// ConvolusionFilter1D, then convolving each column by another one.
//
// Entries are stored in fixed point, shifted left by kShiftBits.
-class ConvolusionFilter1D {
+class ConvolutionFilter1D {
public:
// The number of bits that fixed point values are shifted by.
enum { kShiftBits = 14 };
typedef short Fixed;
- ConvolusionFilter1D() : max_filter_(0) {
+ ConvolutionFilter1D() : max_filter_(0) {
}
// Convert between floating point and our fixed point representation.
@@ -106,7 +106,7 @@ class ConvolusionFilter1D {
int max_filter_;
};
// Does a two-dimensional convolusion on the given source image.
//
// It is assumed the source pixel offsets referenced in the input filters
// reference only valid pixels, so the source image size is not required. Each
@@ -127,8 +127,8 @@ class ConvolusionFilter1D {
void BGRAConvolve2D(const unsigned char* source_data,
int source_byte_row_stride,
bool source_has_alpha,
- const ConvolusionFilter1D& xfilter,
- const ConvolusionFilter1D& yfilter,
+ const ConvolutionFilter1D& xfilter,
+ const ConvolutionFilter1D& yfilter,
unsigned char* output);
} // namespace skia
@@ -18,18 +18,18 @@ namespace skia {
// list by calling AddFilter for each output pixel (in order).
//
-// We do 2-dimensional convolusion by first convolving each row by one
-// ConvolusionFilter1D, then convolving each column by another one.
+// We do 2-dimensional convolution by first convolving each row by one
+// ConvolutionFilter1D, then convolving each column by another one.
//
// Entries are stored in fixed point, shifted left by kShiftBits.
@@ -106,7 +106,7 @@ class ConvolusionFilter1D {
int max_filter_;
};
-// Does a two-dimensional convolusion on the given source image.
+// Does a two-dimensional convolution on the given source image.
//
// It is assumed the source pixel offsets referenced in the input filters